#
# spec file for package ghc-th-orphans
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name th-orphans
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.13.12
Release:        bp154.2.11
Summary:        Orphan instances for TH datatypes
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/2.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-th-compat-devel
BuildRequires:  ghc-th-expand-syns-devel
BuildRequires:  ghc-th-lift-devel
BuildRequires:  ghc-th-lift-instances-devel
BuildRequires:  ghc-th-reify-many-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
Orphan instances for TH datatypes. In particular, instances for Ord and Lift,
as well as a few missing Show / Eq. These instances used to live in
haskell-src-meta, and that's where the version number started.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Tue Nov 16 2021 psimons@suse.com
- Update th-orphans to version 0.13.12 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Sep  2 2021 psimons@suse.com
- Update th-orphans to version 0.13.12 revision 1.
  [#]## 0.13.12 [2021.08.30]
  * Implement `qGetDoc` and `qPutDoc` (introduced in `template-haskell-2.18.0.0`)
    for the `Quasi` instances defined in `th-orphans`.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Sep 30 2020 psimons@suse.com
- Update th-orphans to version 0.13.11.
  [#]## 0.13.11 [2020.09.29]
  * Allow building with `template-haskell-2.17.0.0` (GHC 9.0).
  * Define `Quote` instances for `ReaderT`, `StateT`, `WriterT`, and `RWST`. In
    order to define these instances on as many versions of `template-haskell` as
    possible, this library now depends on the `th-compat` library, which
    backports the `Quote` class to older versions of `template-haskell`.
  * Backport the `Semigroup`, `Monoid`, and `MonadFix` instances for `Q` that
    were introduced in `template-haskell-2.17.0.0`.
* Tue Sep  1 2020 psimons@suse.com
- Update th-orphans to version 0.13.10.
  [#]## 0.13.10 [2020.04.13]
  * Implement `liftTyped` in the `Lift Bytes` instance.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sun Sep 29 2019 psimons@suse.com
- Update th-orphans to version 0.13.9.
  [#]## 0.13.9 [2019.09.28]
  * Implement `qReifyType` (introduced in `template-haskell-2.16.0.0`) for the
    `Quasi` instances defined in `th-orphans`.
* Fri Sep  6 2019 psimons@suse.com
- Update th-orphans to version 0.13.8.
  [#]## 0.13.8 [2019.09.04]
  * Backport the `Bounded` instance for `Extension`
    (from `Language.Haskell.TH.LanguageExtensions`), which was introduced in
    `template-haskell-2.15.0.0`.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Mon Mar 25 2019 psimons@suse.com
- Update th-orphans to version 0.13.7.
  [#]## 0.13.7 [2019.03.24]
  * Backport the `MonadFail Q` instance.
  * Allow building with `template-haskell-2.16` by manually implementing
    `Lift` for `Bytes`. See [#27]
  [#27]: https://github.com/mgsloan/th-orphans/issues/27
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update th-orphans to version 0.13.6.
  [#]## 0.13.6 [2018.07.01]
  * Allow building with `template-haskell-2.14`.
  * Implement `qAddForeignFilePath` and `qAddTempFile` for `Quasi` instances
* Mon May 14 2018 psimons@suse.com
- Update th-orphans to version 0.13.5 revision 1.
  * Implement `qAddCorePlugin` for `Quasi` instances
  * Implement `qAddForeignFile` for `Quasi` instances
* Mon Nov 14 2016 psimons@suse.com
- Update to version 0.13.3 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.13.2 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.13.0 revision 0 with cabal2obs.
